Update of /cvsroot/monetdb/pathfinder/compiler/semantics
In directory sc8-pr-cvs7.sourceforge.net:/tmp/cvs-serv12821/compiler/semantics
Modified Files:
xquery_fo.c
Log Message:
- added a pf:attribute(ctx as node()*, value as xs:string) : element()*
i.e. without attribute uri:loc filter.
Index: xquery_fo.c
===================================================================
RCS file: /cvsroot/monetdb/pathfinder/compiler/semantics/xquery_fo.c,v
retrieving revision 1.115
retrieving revision 1.116
diff -u -d -r1.115 -r1.116
--- xquery_fo.c 4 Apr 2007 22:23:55 -0000 1.115
+++ xquery_fo.c 5 Apr 2007 10:23:15 -0000 1.116
@@ -1760,7 +1760,7 @@
{ .ns = PFns_lib, .loc = "collections-unsafe",
.arity = 0, .sig_count = 1, .sigs = { {
.ret_ty = PFty_star( PFty_xs_anyElement ()) } } }
- , /* pf:attr (node()*, string, string, string) as element()* */
+ , /* pf:attribute (node()*, string, string, string) as element()* */
{ .ns = PFns_lib, .loc = "attribute",
.arity = 4, .sig_count = 1, .sigs = { {
.par_ty = (PFty_t[]) { PFty_star( PFty_xs_anyNode ()),
@@ -1768,7 +1768,13 @@
PFty_xs_string (),
PFty_xs_string () },
.ret_ty = PFty_star( PFty_xs_anyElement ()) } } }
- , /* pf:text (node()*, string, string, string) as element()* */
+ , /* pf:attribute (node()*, string) as element()* */
+ { .ns = PFns_lib, .loc = "attribute",
+ .arity = 2, .sig_count = 1, .sigs = { {
+ .par_ty = (PFty_t[]) { PFty_star( PFty_xs_anyNode ()),
+ PFty_xs_string () },
+ .ret_ty = PFty_star( PFty_xs_anyElement ()) } } }
+ , /* pf:text (node()*, string) as text()* */
{ .ns = PFns_lib, .loc = "text",
.arity = 2, .sig_count = 1, .sigs = { {
.par_ty = (PFty_t[]) { PFty_star( PFty_xs_anyNode ()),
-------------------------------------------------------------------------
Take Surveys. Earn Cash. Influence the Future of IT
Join SourceForge.net's Techsay panel and you'll get the chance to share your
opinions on IT & business topics through brief surveys-and earn cash
http://www.techsay.com/default.php?page=join.php&p=sourceforge&CID=DEVDEV
_______________________________________________
Monetdb-pf-checkins mailing list
[email protected]
https://lists.sourceforge.net/lists/listinfo/monetdb-pf-checkins